@@ -19,7 +19,7 @@
 @CREATED    : Greg Ward, 1996/07/25-28
 @MODIFIED   : Jan 1997
               Jun 1997
-@VERSION    : $Id: lex_auxiliary.c,v 1.31 1999/11/29 01:13:10 greg Rel $
+@VERSION    : $Id: lex_auxiliary.c,v 1.33 2003/10/04 17:27:18 greg Exp $
 @COPYRIGHT  : Copyright (c) 1996-99 by Gregory P. Ward.  All rights reserved.
 
               This file is part of the btparse library.  This library is
@@ -159,7 +159,7 @@ void zzcr_attr (Attrib *a, int tok, char *txt)
       int   len = strlen (txt);
 
       assert ((txt[0] == '{' && txt[len-1] == '}')
-              || (txt[0] == '"' && txt[len-1] == '"'));
+              || (txt[0] == '\"' && txt[len-1] == '\"'));
       txt[len-1] = (char) 0;            /* remove closing quote from string */
       txt++;                            /* so we'll skip the opening quote */
    }
@@ -256,7 +256,7 @@ realloc_lex_buffer (int     size_increment,
 
    beg = zzbegexpr - zzlextext;
    end = zzendexpr - zzlextext;
-   next = *nextpos - zzlextext;
+   next = *nextpos - (unsigned char *) zzlextext;
    zzlextext = zztoktext;
 
    if (lastpos != NULL)
